@@ -1,3 +1,6 @@
+time_before_date <- Sys.Date()
+time_before <- as.character(time_before_date)
+
 repo_pkg <- fake_repo(as.package = TRUE)
 repo_no_pkg <- fake_repo()
 
@@ -5,23 +8,29 @@ repo_no_pkg <- fake_repo()
 files <- list.files(repo_pkg, recursive = TRUE)
 infos <- get_info(files[grep("example", files)], repo = repo_pkg)
 infos_not_in_repo <- get_info(files[grep("my_mean", files)], repo = repo_pkg)
-today <- as.character(Sys.Date())
+
 # if check started one day and finishes the other day
-tomorrow <- as.character(Sys.Date() + 1)
+time_after_date <- Sys.Date()
+time_after <- as.character(time_after_date)
 
 test_that("get_info works", {
   expect_true(infos$in_repository)
   expect_equal(infos$file, "example.txt")
+
+  expect_gte(as.Date(infos$last_modif), time_before_date)
+  expect_lte(as.Date(infos$last_modif), time_after_date)
   expect_true(as.character(as.Date(infos$first_modif)) %in%
-                c(setNames(today, "first"), setNames(tomorrow, "first")))
+                c(setNames(time_before, "first"), setNames(time_after, "first")))
   expect_true(as.character(as.Date(infos$last_modif)) %in%
-                c(setNames(today, "last"), setNames(tomorrow, "first")))
+                c(setNames(time_before, "last"), setNames(time_after, "first")))
 
   expect_false(infos_not_in_repo$in_repository)
   expect_equal(infos_not_in_repo$file, "R/my_mean.R")
   expect_true(is.na(infos_not_in_repo$first_modif))
+  expect_gte(as.Date(infos_not_in_repo$last_modif), time_before_date)
+  expect_lte(as.Date(infos_not_in_repo$last_modif), time_after_date)
   expect_true(as.character(as.Date(infos_not_in_repo$last_modif)) %in%
-               c(setNames(today, "last"), setNames(tomorrow, "first")))
+               c(setNames(time_before, "last"), setNames(time_after, "first")))
 })
 
 # get_last_modif ----
